﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Moq;

/* Unit test with mocking framework. Moq quickstart https://github.com/Moq/moq4/wiki/Quickstart
 * 
 * With mocking framework, you can change the code behavior without making modification.
 * This is  useful when you like to test a method, and that method relies on the output 
 * of the other methods, you can alter the output of the other methods so that you know
 * the method you are testing against can handle diferent scenarios.
 * * 
 * */

namespace IndustryConnect.Bootcamp.UnitTest
{

    [TestClass]
    public class BasicUnitTestsWithMocking // Right click the class name: BasicUnitTests and click Run Tests
    {
        [TestMethod]
        public void TestApplyJob_MockCheckCV()
        {
            // We use moq to make CheckCv throw exception even when it is a good CV!!
            // This way we can test if ApplyJob can handle this exception.
            var mock = new Mock<ICvService>();
            mock.Setup(n => n.CheckCv("Good CV.. Experience..")).Throws<Exception>();

            var cvService = mock.Object; 

            // jobService will use mocked cvService.
            var jobService = new JobService(cvService);

            // Since we mocked the CV service, now we are checking if ApplyJob 
            // handles the exception and return false as exception was forced to be thrown.
            var result = jobService.ApplyJob("Mike", 10, "Good CV.. Experience..");
            Assert.IsFalse(result);
        }

        // .. to be continued during session at Job Ready Programme
    }
}
